#[repr(C)]pub struct ComputedFontStretchRange(pub FontStretch, pub FontStretch);Expand description
The computed representation of the above, so that Gecko and Servo can read them easily.
Tuple Fields
0: FontStretch1: FontStretchTrait Implementations
Sourceimpl Clone for ComputedFontStretchRange
impl Clone for ComputedFontStretchRange
Sourcefn clone(&self) -> ComputedFontStretchRange
fn clone(&self) -> ComputedFontStretchRange
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ComputedFontStretchRange
impl Debug for ComputedFontStretchRange
Sourceimpl<'de> Deserialize<'de> for ComputedFontStretchRange
impl<'de> Deserialize<'de> for ComputedFontStretchRange
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for ComputedFontStretchRange
impl Hash for ComputedFontStretchRange
Sourceimpl MallocSizeOf for ComputedFontStretchRange
impl MallocSizeOf for ComputedFontStretchRange
Sourcefn size_of(&self, ops: &mut MallocSizeOfOps) -> usize
fn size_of(&self, ops: &mut MallocSizeOfOps) -> usize
Measure the heap usage of all descendant heap-allocated structures, but
not the space taken up by the value itself.
Sourceimpl PartialEq for ComputedFontStretchRange
impl PartialEq for ComputedFontStretchRange
Sourceimpl Serialize for ComputedFontStretchRange
impl Serialize for ComputedFontStretchRange
impl StructuralPartialEq for ComputedFontStretchRange