#[repr(C)]pub struct ComputedFontStyleRange(pub FontStyle, pub FontStyle);Expand description
The computed representation of the above, with angles in degrees stored as signed 8.8 fixed-point values, so that Gecko and Servo can read them easily.
Tuple Fields
0: FontStyle1: FontStyleTrait Implementations
Sourceimpl Clone for ComputedFontStyleRange
impl Clone for ComputedFontStyleRange
Sourcefn clone(&self) -> ComputedFontStyleRange
fn clone(&self) -> ComputedFontStyleRange
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ComputedFontStyleRange
impl Debug for ComputedFontStyleRange
Sourceimpl<'de> Deserialize<'de> for ComputedFontStyleRange
impl<'de> Deserialize<'de> for ComputedFontStyleRange
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for ComputedFontStyleRange
impl Hash for ComputedFontStyleRange
Sourceimpl MallocSizeOf for ComputedFontStyleRange
impl MallocSizeOf for ComputedFontStyleRange
Sourcefn size_of(&self, ops: &mut MallocSizeOfOps) -> usize
fn size_of(&self, ops: &mut MallocSizeOfOps) -> usize
Measure the heap usage of all descendant heap-allocated structures, but
not the space taken up by the value itself.
Sourceimpl PartialEq for ComputedFontStyleRange
impl PartialEq for ComputedFontStyleRange
Sourceimpl Serialize for ComputedFontStyleRange
impl Serialize for ComputedFontStyleRange
impl StructuralPartialEq for ComputedFontStyleRange