#[repr(C)]pub struct ComputedFontWeightRange(pub FontWeight, pub FontWeight);Expand description
The computed representation of the above so Gecko and Servo can read them easily.
This one is needed because cbindgen doesn’t know how to generate specified::Number.
Tuple Fields
0: FontWeight1: FontWeightTrait Implementations
Sourceimpl Clone for ComputedFontWeightRange
impl Clone for ComputedFontWeightRange
Sourcefn clone(&self) -> ComputedFontWeightRange
fn clone(&self) -> ComputedFontWeightRange
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ComputedFontWeightRange
impl Debug for ComputedFontWeightRange
Sourceimpl<'de> Deserialize<'de> for ComputedFontWeightRange
impl<'de> Deserialize<'de> for ComputedFontWeightRange
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for ComputedFontWeightRange
impl Hash for ComputedFontWeightRange
Sourceimpl MallocSizeOf for ComputedFontWeightRange
impl MallocSizeOf for ComputedFontWeightRange
Sourcefn size_of(&self, ops: &mut MallocSizeOfOps) -> usize
fn size_of(&self, ops: &mut MallocSizeOfOps) -> usize
Measure the heap usage of all descendant heap-allocated structures, but
not the space taken up by the value itself.
Sourceimpl PartialEq for ComputedFontWeightRange
impl PartialEq for ComputedFontWeightRange
Sourceimpl Serialize for ComputedFontWeightRange
impl Serialize for ComputedFontWeightRange
impl StructuralPartialEq for ComputedFontWeightRange