#[repr(C)]pub struct ComputedFontWidthRange(pub FontWidth, pub FontWidth);Expand description
The computed representation of the above, so that Gecko and Servo can read them easily.
Tuple Fields
0: FontWidth1: FontWidthTrait Implementations
Sourceimpl Clone for ComputedFontWidthRange
impl Clone for ComputedFontWidthRange
Sourcefn clone(&self) -> ComputedFontWidthRange
fn clone(&self) -> ComputedFontWidthRange
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ComputedFontWidthRange
impl Debug for ComputedFontWidthRange
Sourceimpl<'de> Deserialize<'de> for ComputedFontWidthRange
impl<'de> Deserialize<'de> for ComputedFontWidthRange
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for ComputedFontWidthRange
impl Hash for ComputedFontWidthRange
Sourceimpl MallocSizeOf for ComputedFontWidthRange
impl MallocSizeOf for ComputedFontWidthRange
Sourcefn size_of(&self, ops: &mut MallocSizeOfOps) -> usize
fn size_of(&self, ops: &mut MallocSizeOfOps) -> usize
Measure the heap usage of all descendant heap-allocated structures, but
not the space taken up by the value itself.
Sourceimpl PartialEq for ComputedFontWidthRange
impl PartialEq for ComputedFontWidthRange
Sourcefn eq(&self, other: &ComputedFontWidthRange) -> bool
fn eq(&self, other: &ComputedFontWidthRange) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ComputedFontWidthRange
impl Serialize for ComputedFontWidthRange
impl StructuralPartialEq for ComputedFontWidthRange