pub struct FontWidthRange(pub SpecifiedFontWidth, pub SpecifiedFontWidth);Expand description
The font-width descriptor:
https://drafts.csswg.org/css-fonts-4/#descdef-font-face-font-width
Tuple Fields
0: SpecifiedFontWidth1: SpecifiedFontWidthImplementations
Sourceimpl FontWidthRange
impl FontWidthRange
Sourcepub fn compute(&self) -> Option<ComputedFontWidthRange>
pub fn compute(&self) -> Option<ComputedFontWidthRange>
Returns a computed font-width range, or None if any value contains a calc expression that cannot be resolved at parse time.